#[non_exhaustive]pub struct DstOffsetEntry {
pub offset_seconds: i32,
pub valid_starting_us: u64,
pub valid_until_us: Option<u64>,
}Expand description
One DSTOffsetStruct entry for Node::set_dst_offset.
#[non_exhaustive]: construct via DstOffsetEntry::new so future optional
spec fields can be added without a breaking change.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.offset_seconds: i32DST offset in seconds added to the standard offset.
valid_starting_us: u64The UTCTime (epoch µs) at which this DST offset starts.
valid_until_us: Option<u64>The UTCTime (epoch µs) at which it stops, or None for indefinite.
Implementations