#[non_exhaustive]pub struct WindowStatus {
pub status: CommissioningWindowStatus,
pub admin_fabric_index: Option<u8>,
pub admin_vendor_id: Option<u16>,
}Expand description
Snapshot of the AdministratorCommissioning status attributes.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.status: CommissioningWindowStatusCurrent window status.
admin_fabric_index: Option<u8>Fabric index of the admin that opened the window, if any.
admin_vendor_id: Option<u16>Vendor id of the admin that opened the window, if any.